pub struct DevNodeControl { /* private fields */ }Expand description
The barrier’s node seam over the real registry and runtime.
Implementations
Sourceimpl DevNodeControl
impl DevNodeControl
Sourcepub fn new(
registry: Arc<ComponentRegistry>,
swapper: SupportSwapper,
meta: ComponentMeta,
support: SupportModuleRef,
witness_mailbox: Witness,
witness_content: Witness,
) -> Self
pub fn new( registry: Arc<ComponentRegistry>, swapper: SupportSwapper, meta: ComponentMeta, support: SupportModuleRef, witness_mailbox: Witness, witness_content: Witness, ) -> Self
A control seam for one component on one node.